@@ -24,6 +24,9 @@ int main(int argc, const char ** argv)
     commandList.addCommand(new CommandDistance());
 #ifdef COMMAND_WITHIN
     commandList.addCommand(new CommandContain());
+#endif
+#ifdef COMMAND_FIND
+	commandList.addCommand(new CommandFind());
 #endif
     commandList.addCommand(new CommandInfo());
     commandList.addCommand(new CommandPaste());
